@@ -7,6 +7,7 @@
 
 /// make some error. floating Err(..)
 /// ```no_run
+/// errbang!("error.");
 /// errbang!(err::MyError1);
 /// errbang!(err::MyError2, "cannot find.");
 /// errbang!(err::MyError3, "{} is {}", "bar", 2);
@@ -14,10 +15,13 @@
 #[macro_export]
 macro_rules! errbang {
     (@create $kind:ty$(, $format_str:expr$(, $val:expr )* )?$(, @stamp: $flcb:expr$(, $flc:expr)+)?$(, @chain: $eb:expr$(, $e:expr)+)?) => {
-        <$kind>::new(format!(concat!($($eb ,)?"\n"$(, $flcb)?, " {} " $(, $format_str)?, " <{}>") $($(, $e)+)?$($(, $flc)+)?, <$kind>::message() $($(, $val)*)?, stringify!($kind)))
+        $crate::private::Error::msg(<$kind>::new(format!(concat!($($eb ,)?"\n"$(, $flcb)?, " {} " $(, $format_str)?, " <{}>") $($(, $e)+)?$($(, $flc)+)?, <$kind>::message() $($(, $val)*)?, stringify!($kind))))
     };
-    ($kind:ty$(, $format_str:expr$(, $val:expr )* )?) => {
-        Err(errbang!(@create $kind$(, $format_str$(, $val )* )?, @stamp: "[{} {}:{}]", file!(), line!(), column!()).into())
+    ($format_str:literal$(, $val:expr )*) => {
+        Err(errbang!(@create err::__, $format_str$(, $val )*, @stamp: "  [{} {}:{}]", file!(), line!(), column!()).into())
+    };
+    ($kind:ty$(, $format_str:literal$(, $val:expr )* )?) => {
+        Err(errbang!(@create $kind$(, $format_str$(, $val )* )?, @stamp: "  [{} {}:{}]", file!(), line!(), column!()).into())
     };
 }
 
@@ -30,19 +34,26 @@ macro_rules! errbang {
 /// also can
 /// ```no_run
 /// let num_read = errcast!(file.read(&mut buf));
+/// let num_read = errcast!(file.read(&mut buf), "some error.");
 /// ```
 #[macro_export]
 macro_rules! errcast {
     ($result:expr) => {
         match $result {
             Ok(v) => v,
-            Err(e) => return Err(errbang!(@create err::__, @stamp: "[{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>19}⎺↴", e, stringify!($result), " ").into()),
+            Err(e) => return Err(errbang!(@create err::__, @stamp: "  [{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>20}⎺↴", e, stringify!($result), " ").into()),
+        }
+    };
+    ($result:expr, $format_str:literal$(, $val:expr )*) => {
+        match $result {
+            Ok(v) => v,
+            Err(e) => return Err(errbang!(@create err::__, $format_str $(, $val )*, @stamp: "  [{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>20}⎺↴", e, stringify!($result), " ").into()),
         }
     };
     ($result:expr, $kind:ty$(, $format_str:expr$(, $val:expr )* )?) => {
         match $result {
             Ok(v) => v,
-            Err(e) => return Err(errbang!(@create $kind$(, $format_str $(, $val )*)?, @stamp: "[{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>19}⎺↴", e, stringify!($result), " ").into()),
+            Err(e) => return Err(errbang!(@create $kind$(, $format_str $(, $val )*)?, @stamp: "  [{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>20}⎺↴", e, stringify!($result), " ").into()),
         }
     };
 }
@@ -131,19 +142,14 @@ macro_rules! err {
             }
         }
 
-        impl std::error::Error for $kind {
-            fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
-                Some(self)
+        impl core::fmt::Display for $kind {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+                write!(f, " {}", self.chain)
             }
         }
-        impl std::fmt::Display for $kind {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-                write!(f, "{}", self.chain)
-            }
-        }
-        impl std::fmt::Debug for $kind {
-            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-                write!(f, "{}", self.chain)
+        impl core::fmt::Debug for $kind {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+                write!(f, "{0}{1}{0}", "\n".repeat(2), self.chain)
             }
         }
 
@@ -168,6 +174,46 @@ macro_rules! err {
     };
 }
 
+/// panic! with Master Error
+/// ```no_run
+/// errpanic!(err::MyError1);
+/// errpanic!(err::MyError2, "cannot find.");
+/// errpanic!(err::MyError3, "{} is {}", "bar", 2);
+/// ```
+#[macro_export]
+macro_rules! errpanic {
+    ($kind:ty$(, $format_str:expr$(, $val:expr )* )?) => {
+        panic!("{0}{1}{0}\n", "\n".repeat(5), errbang!(@create $kind$(, $format_str$(, $val )* )?, @stamp: "  [{} {}:{}]", file!(), line!(), column!()))
+    };
+}
+
+/// Any type of error can be converted into our Master Error. **(and unwraping)**<br>
+/// `And then panic!`
+/// ```no_run
+/// // example
+/// // <Unwraped Ok> = errcast!(<Any Result>, <Master Err>, <Optional,..>);
+/// let num_read = errcast_panic!(file.read(&mut buf), err::ReadErr, "this is {} data.", "meta");
+/// ```
+/// also can
+/// ```no_run
+/// let num_read = errcast_panic!(file.read(&mut buf));
+/// ```
+#[macro_export]
+macro_rules! errcast_panic {
+    ($result:expr) => {
+        match $result {
+            Ok(v) => v,
+            Err(e) => panic!("{0}{1}{0}\n", "\n".repeat(5), errbang!(@create err::__, @stamp: "  [{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>20}⎺↴", e, stringify!($result), " ")),
+        }
+    };
+    ($result:expr, $kind:ty$(, $format_str:expr$(, $val:expr )* )?) => {
+        match $result {
+            Ok(v) => v,
+            Err(e) => panic!("{0}{1}{0}\n", "\n".repeat(5), errbang!(@create $kind$(, $format_str $(, $val )*)?, @stamp: "  [{} {}:{}]", file!(), line!(), column!(), @chain: "{} {}\n {:>20}⎺↴", e, stringify!($result), " ")),
+        }
+    };
+}
+
 /// matching io::Error and Master Error to use casting error macros<br>
 ///```no_run
 /// io_to_err!(file.seek(SeekFrom::End(0)))?; // <- io::Error to err
@@ -175,22 +221,23 @@ macro_rules! err {
 ///```
 ///```no_run
 /// io_err! {
-///     // std::io::ErrorKind => err::MyError
+///     // core::io::ErrorKind => err::MyError
 ///     UnexpectedEof => err::MyError1
 ///     Interrupted => err::MyError2
 /// }
 ///```
+#[cfg(feature = "std")]
 #[macro_export]
 macro_rules! io_err {
     (
         $($kind:ident => $errkind:ty$(,)?)*
     ) => {
         #[doc(hidden)]
-        pub fn fn_handle_io_to_err<T>(io_error: std::io::Result<T>, file: &str, line :u32, column: u32) -> Result<T> {
+        pub fn fn_handle_io_to_err<T>(io_error: std::io::Result<T>, file: &str, line :u32, column: u32) -> $crate::private::Result<T> {
             match io_error {
                 Err(e) => match e.kind() {
                     $(
-                        std::io::ErrorKind::$kind => Err(errbang!(@create $errkind, "* io to err.", @stamp: "[{} {}:{}]", file, line, column).into()),
+                        std::io::ErrorKind::$kind => Err(errbang!(@create $errkind, "* io to err.", @stamp: "  [{} {}:{}]", file, line, column).into()),
                     )*
                     _ => Err(e.into()),
                 },
@@ -198,13 +245,13 @@ macro_rules! io_err {
             }
         }
         #[doc(hidden)]
-        pub fn fn_handle_err_to_io<T>(m_error: Result<T>, file: &str, line :u32, column: u32) -> std::io::Result<T> {
+        pub fn fn_handle_err_to_io<T>(m_error: $crate::private::Result<T>, file: &str, line :u32, column: u32) -> std::io::Result<T> {
             match m_error {
                 Err(e) => match e {
                     $(
-                        e if errmatch!(e, $errkind) => std::io::Result::Err(std::io::Error::new(std::io::ErrorKind::$kind, format!("[{} {}:{}] io::Error {:-<19} {}", file, line, column, "<", e))),
+                        e if errmatch!(e, $errkind) => std::io::Result::Err(std::io::Error::new(std::io::ErrorKind::$kind, format!("  [{} {}:{}] io::Error {:-<20} {}", file, line, column, "<", e))),
                     )*
-                    _ => std::io::Result::Err(std::io::Error::new(std::io::ErrorKind::Other, format!("[{} {}:{}] io::Error {:-<19} {}", file, line, column, "<", e))),
+                    _ => std::io::Result::Err(std::io::Error::new(std::io::ErrorKind::Other, format!("  [{} {}:{}] io::Error {:-<20} {}", file, line, column, "<", e))),
                 },
                 Ok(t) => std::io::Result::Ok(t),
             }
@@ -212,10 +259,11 @@ macro_rules! io_err {
     };
 }
 
-/// casting std::io Error to Master Error matched by `io_err`
+/// casting core::io Error to Master Error matched by `io_err`
 ///```no_run
 /// io_to_err!(file.seek(SeekFrom::End(0)))?
 ///```
+#[cfg(feature = "std")]
 #[macro_export]
 macro_rules! io_to_err {
     (
@@ -225,10 +273,11 @@ macro_rules! io_to_err {
     };
 }
 
-/// casting Master Error to std::io Error matched by `io_err`
+/// casting Master Error to core::io Error matched by `io_err`
 ///```no_run
 /// err_to_io!(my_seek(0))?
 ///```
+#[cfg(feature = "std")]
 #[macro_export]
 macro_rules! err_to_io {
     (
